@@ -36,19 +36,18 @@
 #' @author Paolo Di Lorenzo \cr
 #' \itemize{
 #'   \item Email: \email{paolo@@dilorenzo.pl}
-#'   \item Website: \url{http://dilorenzo.pl}
-#'   \item Twitter: \url{http://twitter.com/dilorenzopl}
-#'   \item Github: \url{http://www.github.com/pdil/}
+#'   \item Website: \url{https://dilorenzo.pl}
+#'   \item Github: \url{https://github.com/pdil/}
 #' }
 #'
 #' @seealso
 #' Helpful links:
 #' \itemize{
 #'   \item FIPS code information \cr
-#'     \url{http://en.wikipedia.org/wiki/FIPS_county_code}
-#'     \url{http://en.wikipedia.org/wiki/FIPS_state_code}
+#'     \url{https://en.wikipedia.org/wiki/FIPS_county_code}
+#'     \url{https://en.wikipedia.org/wiki/FIPS_state_code}
 #'   \item US Census Shapefiles \cr
-#'     \url{https://www.census.gov/geo/maps-data/data/tiger-cart-boundary.html}
+#'     \url{https://www.census.gov/geographies/mapping-files/time-series/geo/tiger-line-file.html}
 #'   \item Map Features \cr
 #'     \url{https://en.wikipedia.org/wiki/Map_projection}
 #'     \url{https://en.wikipedia.org/wiki/Albers_projection}
@@ -64,6 +63,11 @@
 #' @name usmap
 "_PACKAGE"
 
+## Prevent R CMD check from catching the following variables
+## as missing global variables (used in ggplot2::aes)
+if (getRversion() >= "2.15.1")
+  utils::globalVariables(c("abbr", "county", "group", "x", "y"))
+
 #' Retrieve US map data
 #'
 #' @param regions The region breakdown for the map, can be one of
